@@ -6,7 +6,11 @@ hatMat <- function(x, trace = FALSE,
     ## Purpose: Return Hat matrix of a smoother -- very general (but slow)
     ## -------------------------------------------------------------------------
     ## Author: Martin Maechler, Date:  7 Mar 2001, 11:12
+    stopifnot(is.logical(trace), length(trace) == 1)
     n <- NROW(x)
+    if(is.unsorted(x) && !missing(pred.sm))
+	warning("'x' is not sorted increasingly:\n ",
+		"  this may be inefficient and lead to wrong results")
     y <- pred.sm(x, numeric(n), ...)
     if(!is.numeric(y) || length(y) !=n)
         stop("`pred.sm' does not return a numeric length n vector")
